@@ -11,7 +11,7 @@ use File::Temp;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-07-16'; # DATE
 our $DIST = 'Pod-Weaver-Plugin-Data-Sah-Filter'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 sub _process_filter_module {
     no strict 'refs'; ## no critic: TestingAndDebugging::ProhibitNoStrict
@@ -22,9 +22,12 @@ sub _process_filter_module {
 
     my $filename = $input->{filename};
 
-    # XXX handle dynamically generated module (if there is such thing in the
-    # future)
-    local @INC = ("lib", @INC);
+    # force reload
+    (my $package_pm = "$package.pm") =~ s!::!/!g;
+    delete $INC{$package_pm};
+
+    require Require::Hook::Source::DzilBuild;
+    local @INC = (Require::Hook::Source::DzilBuild->new(zilla => $input->{zilla}, debug=>1), @INC);
 
     my ($rule_cat, $rule_desc, $meta);
     {
@@ -36,6 +39,7 @@ sub _process_filter_module {
         {
             no strict 'refs'; ## no critic: TestingAndDebugging::ProhibitNoStrict
             $meta = $package->meta;
+            #use DD; print "VERSION: "; dd ${"$package\::VERSION"}; print "meta: "; dd $meta;
         }
         $package =~ /\AData::Sah::Filter::\w+::(\w+)::(\w+)\z/
             or $self->log_fatal("Invalid module name $package, please use Data::Sah::Filter::<LANG>::<CATEGORY>::<DESCRIPTION>");
@@ -216,7 +220,7 @@ Pod::Weaver::Plugin::Data::Sah::Filter - Plugin to use when building Data::Sah::
 
 =head1 VERSION
 
-This document describes version 0.003 of Pod::Weaver::Plugin::Data::Sah::Filter (from Perl distribution Pod-Weaver-Plugin-Data-Sah-Filter), released on 2022-07-16.
+This document describes version 0.004 of Pod::Weaver::Plugin::Data::Sah::Filter (from Perl distribution Pod-Weaver-Plugin-Data-Sah-Filter), released on 2022-07-16.
 
 =head1 SYNOPSIS
 
